pub struct ReportBuilder { /* private fields */ }Expand description
Builder for progress reports that rejects reports without trainer/source evidence.
Implementations
Sourceimpl ReportBuilder
impl ReportBuilder
Sourcepub fn report_id(self, value: ProgressReportId) -> Self
pub fn report_id(self, value: ProgressReportId) -> Self
Sets the report id value on this training builder.
Sourcepub fn enrollment_id(self, value: Id) -> Self
pub fn enrollment_id(self, value: Id) -> Self
Sets the enrollment id value on this training builder.
Sourcepub fn session_ref(self, value: SessionRef) -> Self
pub fn session_ref(self, value: SessionRef) -> Self
Sets the session ref value on this training builder.
Sourcepub fn evidence(self, value: Vec<ProgressEvidence>) -> Self
pub fn evidence(self, value: Vec<ProgressEvidence>) -> Self
Returns the evidence recorded on this training contract.
Sourcepub fn milestones(self, value: Vec<Progress>) -> Self
pub fn milestones(self, value: Vec<Progress>) -> Self
Sets the milestones value on this training builder.
Sourcepub fn approval(self, value: ApprovalState) -> Self
pub fn approval(self, value: ApprovalState) -> Self
Sets the approval value on this training builder.